@@ -30,7 +30,7 @@ use base qw/ Astro::FITS::HdrTrans::FITS /;
 
 use vars qw/ $VERSION /;
 
-$VERSION = '1.56';
+$VERSION = "1.57";
 
 # for a constant mapping, there is no FITS header, just a generic
 # header that is constant
@@ -78,9 +78,9 @@ sub to_AIRMASS_END {
   my $self = shift;
   my $FITS_headers = shift;
   my $end_airmass = 1.0;
-  if ( exists $FITS_headers->{"AMEND"} && $FITS_headers->{"AMEND"} ne 'UNKNOWN') {
+  if ( exists $FITS_headers->{"AMEND"} && $FITS_headers->{"AMEND"} !~ /^UNKNOWN/ ) {
     $end_airmass = $FITS_headers->{"AMEND"};
-  } elsif ( exists $FITS_headers->{"AIRMASS"} ) {
+  } elsif ( exists $FITS_headers->{"AIRMASS"} && $FITS_headers->{"AIRMASS"} !~ /^UNKNOWN/  ) {
     $end_airmass = $FITS_headers->{"AIRMASS"};
   }
   return $end_airmass;
@@ -98,9 +98,9 @@ sub to_AIRMASS_START {
   my $self = shift;
   my $FITS_headers = shift;
   my $start_airmass = 1.0;
-  if ( exists $FITS_headers->{"AMSTART"} && $FITS_headers->{"AMSTART"} ne 'UNKNOWN') {
+  if ( exists $FITS_headers->{"AMSTART"} && $FITS_headers->{"AMSTART"} !~ /^UNKNOWN/ ) {
     $start_airmass = $FITS_headers->{"AMSTART"};
-  } elsif ( exists $FITS_headers->{"AIRMASS"} ) {
+  } elsif ( exists $FITS_headers->{"AIRMASS"} && $FITS_headers->{"AIRMASS"} !~ /^UNKNOWN/ ) {
     $start_airmass = $FITS_headers->{"AIRMASS"};
   }
   return $start_airmass;
@@ -134,8 +134,6 @@ values of the C<OBJECT> and C<OBSTYPE> keywords.  The default is
 
 =cut
 
-# No clue what the recipe is apart for a dark and assume a dither
-# pattern means JITTER_SELF_FLAT.
 sub to_DR_RECIPE {
   my $self = shift;
   my $FITS_headers = shift;
@@ -395,7 +393,7 @@ sub dms_to_degrees {
   my $sexa = shift;
   my $dms;
   if ( defined( $sexa ) ) {
-    if ($sexa =~ /UNKNOWN/i or $sexa eq "N/A" ) {
+    if ($sexa =~ /UNKNOWN/i or $sexa eq "N/A" or $sexa eq "NaN" ) {
       $dms = 0.0;
     } else {
       my @pos = split( /:/, $sexa );
@@ -421,7 +419,7 @@ sub hms_to_degrees {
   my $sexa = shift;
   my $hms;
   if ( defined( $sexa ) ) {
-    if ($sexa =~ /UNKNOWN/i or $sexa eq "N/A" ) {
+    if ($sexa =~ /UNKNOWN/i or $sexa eq "N/A" or $sexa eq "NaN" ) {
       $hms = 0.0;
     } else {
       my @pos = split( /:/, $sexa );
